@@ -42,7 +42,6 @@ NamespacePtr	CairoImageNamespace;
 NamespacePtr	CairoPdfNamespace;
 NamespacePtr	CairoSvgNamespace;
 NamespacePtr	CairoPsNamespace;
-NamespacePtr	CairoRsvgNamespace;
 Type		*typeCairo;
 Type		*typeCairoSurface;
 Type		*typeCairoStatus;
@@ -64,16 +63,11 @@ Type		*typeCairoPath;
 Type		*typeCairoCurveTo;
 Type		*typeCairoScaledFont;
 Type		*typeCairoFontFace;
-Type		*typeCairoContent;
 
 Type		*typeCairoPatternExtend;
 Type		*typeCairoPatternFilter;
 Type		*typeCairoImageFormat;
 
-Type		*typeRsvg;
-Type		*typeRsvgDimensions;
-Type		*typeRsvgPosition;
-
 #define CAIRO_I		0
 #define CAIRO_S		"00"
 #define SURFACE_I	1
@@ -116,8 +110,6 @@ Type		*typeRsvgPosition;
 #define SCALED_FONT_S	"22"
 #define FONT_FACE_I	23
 #define FONT_FACE_S	"23"
-#define CONTENT_I	24
-#define CONTENT_S	"24"
 
 #define EXTEND_I	30
 #define EXTEND_S	"30"
@@ -127,15 +119,6 @@ Type		*typeRsvgPosition;
 #define FORMAT_I	32
 #define FORMAT_S	"32"
 
-#define RSVG_I		33
-#define RSVG_S		"33"
-
-#define RSVG_DIMENSIONS_I	34
-#define RSVG_DIMENSIONS_S	"34"
-
-#define RSVG_POSITION_I	35
-#define RSVG_POSITION_S	"35"
-
 static Type *
 make_typedef (char	*name_str,
 	      Namespace	*namespace,
@@ -356,16 +339,6 @@ init_types (void)
 				     NULL,
 				     typePrim[rep_foreign]);
 
-    typeCairoContent = make_typedef ("content_t",
-				     CairoNamespace,
-				     publish_public,
-				     CONTENT_I,
-				     NULL,
-				     BuildEnumType (3,
-						    "COLOR",
-						    "ALPHA",
-						    "COLOR_ALPHA"));
-
     /*
      * Path data structures
      */
@@ -454,34 +427,6 @@ init_types (void)
 				      NULL,
 				      typePrim[rep_foreign]);
 
-    CairoRsvgNamespace = BuiltinNamespace(&CairoNamespace, "Rsvg")->namespace.namespace;
-
-    typeRsvgDimensions = make_typedef("dimensions_t",
-				      CairoRsvgNamespace,
-				      publish_public,
-				      RSVG_DIMENSIONS_I,
-				      NULL,
-				      BuildStructType(4,
-						      typePrim[rep_int], "width",
-						      typePrim[rep_int], "height",
-						      typePrim[rep_float], "em",
-						      typePrim[rep_float], "ex"));
-    typeRsvgPosition = make_typedef("position_t",
-				      CairoRsvgNamespace,
-				      publish_public,
-				      RSVG_POSITION_I,
-				      NULL,
-				      BuildStructType(2,
-						      typePrim[rep_int], "x",
-						      typePrim[rep_int], "y"));
-
-    typeRsvg = make_typedef("rsvg_t",
-			    CairoRsvgNamespace,
-			    publish_public,
-			    RSVG_I,
-			    NULL,
-			    typePrim[rep_foreign]);
-			    
     EXIT();
 }
 
@@ -495,9 +440,9 @@ EnumIntPart (Value ev, char *err)
     for (i = 0; i < st->nelements; i++)
 	if (StructTypeAtoms(st)[i] == u->tag)
 	    return i;
-    RaiseStandardException (exception_invalid_argument, 3,
-			    NewStrString (err),
-			    NewInt (0), ev);
+    RaiseStandardException (exception_invalid_argument,
+			    err,
+			    2, 0, ev);
     return -1;
 }
 
@@ -511,9 +456,9 @@ IntToEnum (Type *type, int i)
 
     if (i < 0 || st->nelements <= i)
     {
-	RaiseStandardException (exception_invalid_argument, 3,
-				NewStrString ("invalid enum index"),
-				NewInt (i), v);
+	RaiseStandardException (exception_invalid_argument,
+				"invalid enum index",
+				2, NewInt (i), v);
 	RETURN (Void);
     }
     
@@ -919,10 +864,6 @@ nickle_init (void)
 	    " file open_event (surface_t surface)\n"
 	    "\n"
 	    " Returns a file which will receive events\n" },
-	{ do_Cairo_Surface_status, "status", STATUS_S, SURFACE_S, "\n"
-	    " status_t status (surface_t surface)\n"
-	    "\n"
-	    " Return status associated with surface.\n" },
 	{ 0 }
     };
 
@@ -935,12 +876,6 @@ nickle_init (void)
 	    " void write_to_png (surface_t surface, file f)\n"
 	    "\n"
 	    " Write a surface to f in png format\n" },
-#if HAVE_CAIRO_XLIB_H
-	{ do_Cairo_Surface_set_window_shown, "set_window_shown", "v", SURFACE_S "b", "\n"
-	  " void set_window_shown (surface_t surface, bool shown)\n"
-	  "\n"
-	  " Show or hide the specified window\n" },
-#endif
 	{ 0 }
     };
     
@@ -949,16 +884,12 @@ nickle_init (void)
 	{ do_Cairo_Surface_create_window, "create_window", SURFACE_S, "snn", "\n"
 	    " surface_t create_window (real width, real height)\n"
 	    "\n"
-	    " Create a window, show it, and return a surface pointer for it\n" },
-	{ do_Cairo_Surface_create_window_hidden, "create_window_hidden", SURFACE_S, "snn", "\n"
-	    " surface_t create_window_hidden (real width, real height)\n"
-	    "\n"
-	    " Create a window, but do not show it, and return a surface pointer for it\n" },
-	{ do_Cairo_Surface_resize_window, "resize_window", "v",  SURFACE_S "nn", "\n"
-	    " void resize_window (surface_t surface, real width, real height)\n"
-	    "\n"
-	    " Request that a window be resized. A configure event will signal the new size.\n" },
+	    " Create a window and return a surface pointer for it\n" },
 #endif
+	{ do_Cairo_Surface_create_similar, "create_similar", SURFACE_S, SURFACE_S "nn", "\n"
+	    " surface_t create_similar (surface_t related, real width, real height)\n"
+	    "\n"
+	    " Create a similar surface related to another surface\n" },
 	{ do_Cairo_Surface_set_device_offset, "set_device_offset", "v", SURFACE_S "nn", "\n"
 	    " void set_device_offset (surface_t surface, real x, real y)\n"
 	    "\n"
@@ -966,14 +897,6 @@ nickle_init (void)
 	{ 0 }
     };
 
-    static const struct fbuiltin_4 surfuncs_4[] = {
-	{ do_Cairo_Surface_create_similar, "create_similar", SURFACE_S, SURFACE_S CONTENT_S "ii", "\n"
-	    " surface_t create_similar (surface_t related, content_t content, int width, int height)\n"
-	    "\n"
-	    " Create a similar surface related to another surface\n" },
-	{ 0 }
-    };
-
     static const struct fbuiltin_1 patfuncs_1[] = {
 	{ do_Cairo_Pattern_create_for_surface, "create_for_surface", PATTERN_S, SURFACE_S, "\n"
 	    " pattern_t create_for_surface (surface_t surface)\n"
@@ -1124,57 +1047,6 @@ nickle_init (void)
     };
 #endif
 					 
-    static const struct fbuiltin_1 rsvgfuncs_1[] = {
-	{ do_Rsvg_new_from_string, "new_from_string", RSVG_S, "s", "\n"
-	  " rsvg_t new_from_string (string svg)\n"
-	  "\n"
-	  " Create an RSVG object from the specified SVG string\n" },
-	{ do_Rsvg_new_from_file, "new_from_file", RSVG_S, "s", "\n"
-	  " rsvg_t new_from_file (string file)\n"
-	  "\n"
-	  " Create an RSVG object from the specified SVG file\n" },
-	{ do_Rsvg_get_dimensions, "get_dimensions", RSVG_DIMENSIONS_S, RSVG_S, "\n"
-	  " dimensions_t get_dimensions(rsvg_t rsvg)\n"
-	  "\n"
-	  " Get the dimensions and ex/em values for the specified SVG\n" },
-	{ do_Rsvg_get_title, "get_title", "s", RSVG_S, "\n"
-	  " string get_title(rsvg_t rsvg)\n"
-	  "\n"
-	  " Get the title of specified SVG\n" },
-	{ do_Rsvg_get_desc, "get_desc", "s", RSVG_S, "\n"
-	  " string get_desc(rsvg_t rsvg)\n"
-	  "\n"
-	  " Get the description of specified SVG\n" },
-	{ do_Rsvg_get_metadata, "get_metadata", "s", RSVG_S, "\n"
-	  " string get_metadata(rsvg_t rsvg)\n"
-	  "\n"
-	  " Get the metadata of specified SVG\n" },
-	{ 0 }
-    };
-
-    static const struct fbuiltin_2 rsvgfuncs_2[] = {
-	{ do_Rsvg_render, "render", "v", RSVG_S CAIRO_S, "\n"
-	  " void render (rsvg_t rsvg, cairo_t cairo)\n"
-	  "\n"
-	  " Draw an RSVG object using the specified cairo context\n" },
-	{ do_Rsvg_get_dimensions_sub, "get_dimensions_sub", RSVG_DIMENSIONS_S, RSVG_S "s", "\n"
-	  " dimensions_t get_dimensions_sub(rsvg_t rsvg, string id)\n"
-	  "\n"
-	  " Get the dimensions and ex/em values for the specified 'id' subset of an SVG\n" },
-	{ do_Rsvg_get_position_sub, "get_position_sub", RSVG_POSITION_S, RSVG_S "s", "\n"
-	  " position_t get_position_sub(rsvg_t rsvg, string id)\n"
-	  "\n"
-	  " Get the position of the specified 'id' subset of an SVG\n" },
-	{ 0 }
-    };
-
-    static const struct fbuiltin_3 rsvgfuncs_3[] = {
-	{ do_Rsvg_render_sub, "render_sub", "v", RSVG_S CAIRO_S "s", "\n"
-	  " void render_sub (rsvg_t rsvg, cairo_t cairo, string id)\n"
-	  "\n"
-	  " Draw the 'id' subset of an RSVG object using the specified cairo context\n" },
-	{ 0 }
-    };
     init_types ();
     
     BuiltinFuncs1 (&CairoNamespace, funcs_1);
@@ -1188,7 +1060,6 @@ nickle_init (void)
     BuiltinFuncs1 (&CairoSurfaceNamespace, surfuncs_1);
     BuiltinFuncs2 (&CairoSurfaceNamespace, surfuncs_2);
     BuiltinFuncs3 (&CairoSurfaceNamespace, surfuncs_3);
-    BuiltinFuncs4 (&CairoSurfaceNamespace, surfuncs_4);
     
     BuiltinFuncs1 (&CairoPatternNamespace, patfuncs_1);
     BuiltinFuncs2 (&CairoPatternNamespace, patfuncs_2);
@@ -1211,11 +1082,5 @@ nickle_init (void)
     BuiltinFuncs3 (&CairoPsNamespace, psfuncs_3);
 #endif
 
-    rsvg_init();
-
-    BuiltinFuncs1 (&CairoRsvgNamespace, rsvgfuncs_1);
-    BuiltinFuncs2 (&CairoRsvgNamespace, rsvgfuncs_2);
-    BuiltinFuncs3 (&CairoRsvgNamespace, rsvgfuncs_3);
-
     RETURN(TrueVal);
 }
